@@ -27,6 +27,8 @@ public:
     void addSearchProvider(SearchProvider* provider);
     void removeSearchProvider(SearchProvider* provider);
     QString barcodeText;
+private slots:
+    void barcodeAnalysed(QString barcodeType, QString barcodeData);
 private:
     MainWindow *parent;
     QString url;
